#!/usr/bin/env jython
# -*- coding: utf8 -*-

__version__ = '$Id: jdbc_pg_float_time.py 2524 2015-10-19 08:29:48Z mn $'

import sys
import time
import traceback

from java.sql import DriverManager
from java.lang import Class

Class.forName("org.postgresql.Driver")


def show_meta_data(rs):
	rsmd = rs.getMetaData()
	type_id = rsmd.getColumnType(1)
	type_name = rsmd.getColumnTypeName(1)
	precision = rsmd.getPrecision(1)
	scale = rsmd.getScale(1)
	column_class_name = rsmd.getColumnClassName(1)
	print('column type: %s (%d); java: %s; precision: %d; scale: %d' % (type_name, type_id, column_class_name, precision, scale))



def test(db_url, user, passwd):
	try:
		print("\n\n%s\n--------------" % (db_url))
		db = DriverManager.getConnection(db_url, user, passwd)
		try:
			sel_ver = "SELECT version()"
			sel_float = "SELECT 1445006113904::float8"

			pstmt = db.prepareStatement(sel_ver)
			rs = pstmt.executeQuery()
			while rs.next():
				s = rs.getString(1)
				print(s)
			rs.close()
			pstmt.close()

			dbmi = db.getMetaData()
			print("JDBC driver version is '%s'; major: %s; minor: %s" % (dbmi.getDriverVersion(), dbmi.getDriverMajorVersion(), dbmi.getDriverMinorVersion()))

			print('\ntesting with query: %s\n' % (sel_float))

			last_s = ''
			last_d = 0.0
			i = 0
			t0 = time.time()
			for i in range(3):
				i += 1
				pstmt = db.prepareStatement(sel_float)
				rs = pstmt.executeQuery()
				try:
					print('--- %d ---' % (i))
					show_meta_data(rs)
					while rs.next():
						s = rs.getString(1)
						print('getString(): %s' % (s))
						if '.' in s:
							print('\t\tSTRING FORMAT CHANGED!!!')
							return
				finally:
					rs.close()
					pstmt.close()
		finally:
			db.close()
	except:
		print("there were errors!")
		s = traceback.format_exc()
		sys.stderr.write("%s\n" % (s))


test('jdbc:postgresql://test-baza.heuthesd:5494/isof_test?stringtype=unspecified&prepareThreshold=2', 'postgres', 'postgres')
